<?php

namespace Drupal\paragraph_lineage\Plugin\views\field;

use Drupal\Core\Url;
use Drupal\views\Annotation\ViewsField;
use Drupal\views\Plugin\views\field\FieldPluginBase;
use Drupal\views\ResultRow;

/**
 * A custom views field that provides a link to paragraph lineage.
 *
 * @ViewsField("file_usage_paragraph_link")
 */
class FileUsageParagraphLink extends FieldPluginBase {

  /**
   * {@inheritdoc}
   */
  public function render(ResultRow $values): array {
    $entity_id = $this->getValue($values);

    if (empty($entity_id)) {
      return [];
    }

    try {
      $url = Url::fromRoute('entity.paragraph.canonical', ['paragraph' => $entity_id]);
      return [
        '#type' => 'link',
        '#title' => $this->t('View lineage'),
        '#url' => $url,
        '#attributes' => [
          'class' => ['paragraph-lineage-link'],
        ],
      ];
    }
    catch (\Exception $e) {
      \Drupal::logger('paragraph_lineage')->error('Error creating URL for paragraph ID @id: @message', [
        '@id' => $entity_id,
        '@message' => $e->getMessage(),
      ]);
      return [];
    }
  }

  /**
   * {@inheritdoc}
   */
  public function query() {
    // This field doesn't need to add anything to the query.
  }

}
